/*
 * System Taskbar Tray
 * 
 * Copyright (c) RegExLab.com
 * 
 * 2006.03.27 Chongqing China.
 */
package com.regexlab.j2e;

/**
 * System Tray icon class.
 * 
 * @author sswater shi
 */
public class SystemTray
{
    /** win2k style balloon info type */
    public static final int INFOTYPE_NONE    = 0x00000000;
    /** win2k style balloon info type */
    public static final int INFOTYPE_INFO    = 0x00000001;
    /** win2k style balloon info type */
    public static final int INFOTYPE_WARNING = 0x00000002;
    /** win2k style balloon info type */
    public static final int INFOTYPE_ERROR   = 0x00000003;

    /** system tray mouse event */
    public final static int MOUSE_MOVE          = 0x0200;
    /** system tray mouse event */
    public final static int LEFT_CLICK          = 0x0202;
    /** system tray mouse event */
    public final static int LEFT_DOUBLE_CLICK   = 0x0203;
    /** system tray mouse event */
    public final static int RIGHT_CLICK         = 0x0205;
    /** system tray mouse event */
    public final static int RIGHT_DOUBLE_CLICK  = 0x0206;
    /** system tray mouse event */
    public final static int MIDDLE_CLICK        = 0x0208;
    /** system tray mouse event */
    public final static int MIDDLE_DOUBLE_CLICK = 0x0209;

    /** balloon clicked */
    public final static int NIN_BALLOONUSERCLICK = 0x0405;
    
    /**
     * Construct a SystemTray without windows 2000 style balloon info.
     * 
     * @param nIcon - Icon number in the exefile. The first icon's number is 1. 
     * @param szTip - Tooltip text of the icon.
     */
    public SystemTray(int nIcon, String szTip)
    {
        init(nIcon, szTip, null, null, 0);
    }

    /**
     * Construct a SystemTray with windows 2000 style balloon info. If this exe is runing under
     * win9x or winnt4.0, the balloon info will not be shown.
     * 
     * @param nIcon - Icon number in the exefile. The first icon's number is 1. 
     * @param szTip - Tooltip text of the icon.
     * @param szInfo - Balloon info text.
     * @param szInfoTitle - Balloon info title.
     * @param nInfoType - Icon type of the balloon info.
     */
    public SystemTray(int nIcon, String szTip, String szInfo, String szInfoTitle, int nInfoType)
    {
        init(nIcon, szTip, szInfo, szInfoTitle, nInfoType);
    }

    /**
     * Change the system tray.
     * 
     * @param nIcon - Icon number in the exefile. The first icon's number is 1. 
     * @param szTip - Tooltip text of the icon.
     */
    public void Change(int nIcon, String szTip)
    {
        Change(nIcon, szTip, null, null, -1);
    }

    /**
     * Change the system tray.
     * 
     * @param nIcon - Icon number in the exefile. The first icon's number is 1. 
     * @param szTip - Tooltip text of the icon.
     * @param szInfo - Balloon info text.
     * @param szInfoTitle - Balloon info title.
     * @param nInfoType - Icon type of the balloon info.
     */
    public native void Change(int nIcon, String szTip, String szInfo, String szInfoTitle, int nInfoType);

    /** Show system tray. */
    public native void Show();
    
    /** Hide system tray. */
    public native void Hide();
    
    /**
     * Set the mouse event callback handler. 
     * 
     * @param callback - Handler to receive mouse event.
     */
    public static native void setSystemTrayCallback(SystemTrayCallback callback);

    protected native void init(int nIcon, String szTip, String szInfo, String szInfoTitle, int nInfoType);
    protected native void finalize ();
    protected long h = 0;

    static
    {
        String j2epath = System.getProperty("j2e.app.path");
        if( j2epath != null )
            System.load( j2epath );
    }
}
